@@ -533,6 +533,13 @@ class Calc(ItclObjectx, Frame) :
         #---------------------------------------------------------------------
         # calculator bindings
         #---------------------------------------------------------------------
+        for c in ["disp", "state_a", "state_h", "state_d", "state_m", "state_s"] :
+            w = self.__Component[c]
+            w.bind("<Enter>", focuscmd)
+            w.bind("<Leave>", unfocuscmd)
+            wx = list(w.bindtags())
+            wx.insert(0, self)
+            w.bindtags(tuple(wx))
         self.bind("<Return>",          eqcmd)
         self.bind("<space>",           eqcmd)
         self.bind("<BackSpace>",       bscmd)
@@ -542,15 +549,17 @@ class Calc(ItclObjectx, Frame) :
         #---------------------------------------------------------------------
         # update / mainloop
         #---------------------------------------------------------------------
+        if self.__toplevel:
+            self.__toplevel.wm_title("calc")
         if self.__wait :
             self.wait_window()
     #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     # Calc buttons callback methods
     #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
-    #--------------------------------------------------------------------------
+    #===========================================================================
     # METHOD  : num
     # PURPOSE : enter one digit of a number
-    #--------------------------------------------------------------------------
+    #===========================================================================
     def num (self, button) :
         if (self.mode == ">") :
             self.x = []
@@ -565,10 +574,10 @@ class Calc(ItclObjectx, Frame) :
             self.x.append(button)
             self.mode = "X"
         self.__dispx__()
-    #--------------------------------------------------------------------------
+    #===========================================================================
     # METHOD  : pt
     # PURPOSE : decimal point
-    #--------------------------------------------------------------------------
+    #===========================================================================
     def pt (self, button) :
         if (self.mode == ">") :
             self.x = []
@@ -579,10 +588,10 @@ class Calc(ItclObjectx, Frame) :
             self.x.append(".")
             self.mode = "F"
         self.__dispx__()
-    #--------------------------------------------------------------------------
+    #===========================================================================
     # METHOD  : EE
     # PURPOSE : enter exponent
-    #--------------------------------------------------------------------------
+    #===========================================================================
     def EE (self, button) :
         if (self.mode in ["I", "F"]) :
             self.x.append("E")
@@ -591,10 +600,10 @@ class Calc(ItclObjectx, Frame) :
             self.x.append("0")
             self.mode = "E"
         self.__dispx__()
-    #--------------------------------------------------------------------------
+    #===========================================================================
     # METHOD  : porm
     # PURPOSE : enter +/-
-    #--------------------------------------------------------------------------
+    #===========================================================================
     def porm (self, button) :
         if (self.mode in [">", "I", "F"]) :
             if (self.x[0] == "-") :
@@ -607,89 +616,134 @@ class Calc(ItclObjectx, Frame) :
             elif (self.x[-3] == "-") :
                 self.x[-3] = "+"
         self.__dispx__()
-    #--------------------------------------------------------------------------
+    #===========================================================================
     # METHOD  : OFF
     # PURPOSE : shut down
-    #--------------------------------------------------------------------------
+    #===========================================================================
     def OFF (self, button) :
         self.quit()
         if self.__toplevel :
             self.__toplevel.destroy()
         else :
             self.destroy()
-
+    #===========================================================================
+    # METHOD  : CE
+    # PURPOSE : clear entry
+    #===========================================================================
     def CE (self, button) :
         self.CLX()
-
+    #===========================================================================
+    # METHOD  : AC
+    # PURPOSE : clear all
+    #===========================================================================
     def AC (self, button) :
         self.CLX()
         self.CLM()
         self.CLA()
         self.STK = []
-
+    #===========================================================================
+    # METHOD  : pi
+    # PURPOSE : enter pi
+    #===========================================================================
     def pi (self, button) :
         self.STX(pi)
-
+    #===========================================================================
+    # METHOD  : e
+    # PURPOSE : enter e
+    #===========================================================================
     def e (self, button) :
         self.STX(exp(1))
-
+    #===========================================================================
+    # METHOD  : const
+    # PURPOSE : display constant dialog
+    #===========================================================================
     def const (self, button) :
       u = self.constant()
       if not u is None :
          self.STX(u)
-
+    #===========================================================================
+    # METHOD  : put
+    # PURPOSE : put accumulator into constant database
+    #===========================================================================
     def put (self, button) :
       x = self.GTX()
       self.__saved_constants.append(
           "%-16s               saved result" % (str(x)))
-
+    #===========================================================================
+    # METHOD  : sqr
+    # PURPOSE : x^2
+    #===========================================================================
     def sqr (self, button) :
       x = self.GTX()
       self.STX(x*x)
-
+    #===========================================================================
+    # METHOD  : sqrt
+    # PURPOSE : sqrt(x)
+    #===========================================================================
     def sqrt (self, button) :
       x = self.GTX()
       if (x < 0) :
          self.messagebox("error: x<0")
       else :
          self.STX(sqrt(x))
-
+    #===========================================================================
+    # METHOD  : inv
+    # PURPOSE : 1/x
+    #===========================================================================
     def inv (self, button) :
       x = self.GTX()
       if (x == 0) :
          self.messagebox("error: x=0")
       else :
          self.STX(1.0/x)
-
+    #===========================================================================
+    # METHOD  : tenx
+    # PURPOSE : 10^x
+    #===========================================================================
     def tenx (self, button) :
       x = self.GTX()
       self.STX(10.0**x)
-
+    #===========================================================================
+    # METHOD  : exp
+    # PURPOSE : e^x
+    #===========================================================================
     def exp (self, button) :
       x = self.GTX()
       self.STX(exp(x))
- 
+    #===========================================================================
+    # METHOD  : log
+    # PURPOSE : log10(x)
+    #===========================================================================
     def log (self, button) :
       x = self.GTX()
       if (x <= 0) :
         self.messagebox("error: x<=0")
       else :
         self.STX(log10(x))
-
+    #===========================================================================
+    # METHOD  : ln
+    # PURPOSE : ln(x)
+    #===========================================================================
     def ln (self, button) :
       x = self.GTX()
       if (x <= 0) :
         self.messagebox("error: x<=0")
       else :
         self.STX(log(x))
- 
+    #===========================================================================
+    # METHOD  : ytox
+    # PURPOSE : y^x
+    #===========================================================================
     def ytox (self, button) :
       x = self.GTX()
       self.PSH(str(x))
       self.PSH("**")
       self.mode = ">"
       self.__dispx__()
-
+    #===========================================================================
+    # METHOD  : fact
+    # PURPOSE : x!
+    #===========================================================================
     def fact (self, button) :
       x = self.GTX()
       if ((x < 0) or (x > 170)) :
@@ -699,6 +753,10 @@ class Calc(ItclObjectx, Frame) :
           for i in range(1, int(x+1)) :
               u *= i
           self.STX(u)
+    #===========================================================================
+    # METHOD  : trig
+    # PURPOSE : sin/cos/tan, asin/acos/atan, sinh/cosh/tanh, asinh/acosh/atanh
+    #===========================================================================
     def trig (self, button) :
       x = self.GTX()
       if (not(self.hyp)) :
@@ -724,7 +782,10 @@ class Calc(ItclObjectx, Frame) :
               self.STX(x)
       self.arc = 0
       self.hyp = 0
-
+    #===========================================================================
+    # METHOD  : pmin
+    # PURPOSE : +,-
+    #===========================================================================
     def pmin(self, button) :
       if (self.mode == "E") :
           self.x[-3] = button
@@ -737,7 +798,10 @@ class Calc(ItclObjectx, Frame) :
           x = self.GTX()
           self.PSH(str(x))
           self.PSH(button)
-
+    #===========================================================================
+    # METHOD  : mdiv
+    # PURPOSE : *,/
+    #===========================================================================
     def mdiv(self, button) :
         x = self.GTX()
         self.PSH(str(x))
@@ -746,24 +810,36 @@ class Calc(ItclObjectx, Frame) :
         x = self.GTX()
         self.PSH(str(x))
         self.PSH(button)
-
+    #===========================================================================
+    # METHOD  : lpar
+    # PURPOSE : (
+    #===========================================================================
     def lpar(self, button) :
        if (self.mode == ">") :
            self.PSH(button)
-
+    #===========================================================================
+    # METHOD  : rpar
+    # PURPOSE : )
+    #===========================================================================
     def rpar(self, button) :
        x = self.GTX()
        self.PSH(str(x))
        x = self.PEX(["("])
        self.STX(x)
        self.POP()
-
+    #===========================================================================
+    # METHOD  : eq
+    # PURPOSE : =
+    #===========================================================================
     def eq (self, button) :
         x = self.GTX()
         self.PSH(str(x))
         x = self.PEX()
         self.STX(x)
-
+    #===========================================================================
+    # METHOD  : HELP
+    # PURPOSE : display help dialog
+    #===========================================================================
     def HELP(self, button) :
         text = []
         text.append("Button:\tKey-binding:\n")
@@ -773,50 +849,81 @@ class Calc(ItclObjectx, Frame) :
         text.append("=\t<Return>\n")
         text.append("=\t<space>\n")
         self.messagebox(string.join(text, ""))
-
+    #===========================================================================
+    # METHOD  : DRG
+    # PURPOSE : degree/radian/grad
+    #===========================================================================
     def DRG(self, button) :
        self.drg = (self.drg + 1) % 3
        self.__dispa__()
-
+    #===========================================================================
+    # METHOD  : ARC
+    # PURPOSE : arc
+    #===========================================================================
     def ARC(self, button) :
        self.arc = not(self.arc)
        self.__dispa__()
-
+    #===========================================================================
+    # METHOD  : HYP
+    # PURPOSE : hy
+    #===========================================================================
     def HYP(self, button) :
        self.hyp = not(self.hyp)
        self.__dispa__()
-
+    #===========================================================================
+    # METHOD  : Mp
+    # PURPOSE : add to memory
+    #===========================================================================
     def Mp(self, button) :
        x = self.GTX()
        m = self.GTM()
        m = m + x
        self.STM(m)
-
+    #===========================================================================
+    # METHOD  : Mm
+    # PURPOSE : subtract from memory
+    #===========================================================================
     def Mm(self, button) :
        x = self.GTX()
        m = self.GTM()
        m = m - x
        self.STM(m)
-
+    #===========================================================================
+    # METHOD  : STO
+    # PURPOSE : store in memory
+    #===========================================================================
     def STO(self, button) :
        x = self.GTX()
        self.STM(x)
-
+    #===========================================================================
+    # METHOD  : RCL
+    # PURPOSE : recall from memory
+    #===========================================================================
     def RCL(self, button) :
        m = self.GTM()
        self.STX(m)
-
+    #===========================================================================
+    # METHOD  : XCH
+    # PURPOSE : exchange accumulator and memory
+    #===========================================================================
     def XCH(self, button) :
        x = self.GTX()
        m = self.GTM()
        self.STX(m)
        self.STM(x)
+    #===========================================================================
+    # METHOD  : CLR
+    # PURPOSE : clear memory
+    #===========================================================================
     def CLR(self, button) :
        self.CLM()
-
     #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     # binding and menu commands
     #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+    #===========================================================================
+    # METHOD  : BS
+    # PURPOSE : back-space
+    #===========================================================================
     def BS(self) :
        x = string.join(self.x, "")
        if (len(x) == 1) :
@@ -834,10 +941,6 @@ class Calc(ItclObjectx, Frame) :
               u = x[:-1]
               self.x = [u]
               self.mode = "I"
-           elif x[-2] == "." :
-              u = x[:-2]
-              self.x = [u]
-              self.mode = "I"
            else :
               u = x[:-1]
               self.x = [u]
@@ -849,14 +952,23 @@ class Calc(ItclObjectx, Frame) :
            else :
                self.mode = "I"
        self.__dispx__()
-
+    #===========================================================================
+    # METHOD  : RAND
+    # PURPOSE : enter a random-number
+    #===========================================================================
     def RAND(self) :
         self.STX(random.random())
-
+    #===========================================================================
+    # METHOD  : SEED
+    # PURPOSE : use accumulator as a random seed
+    #===========================================================================
     def SEED(self) :
         x=self.GTX()
-        random.random_seed(x)
-
+        random.seed(x)
+    #===========================================================================
+    # METHOD  : STKQ
+    # PURPOSE : print out stack
+    #===========================================================================
     def STKQ(self) :
         text = []
         text.append("LOC:\tVALUE:\nX:\t" + str(self.x) + "\n")
@@ -864,7 +976,10 @@ class Calc(ItclObjectx, Frame) :
         for i, entry in enumerate(self.STK) :
             text.append(str(i) + ":\t" + entry)
         self.messagebox(string.join(text, ""))
-
+    #===========================================================================
+    # METHOD  : PREC
+    # PURPOSE : use accumulator to set precision
+    #===========================================================================
     def PREC(self) :
         if ((self.x < 1) or (self.x >= 18)) :
             self.messagebox("error: x < 1 or x >= 18")
@@ -872,7 +987,10 @@ class Calc(ItclObjectx, Frame) :
             p = int(self.x)
             tcl_precision = p
             self.messagebox("PRECISION = " + str(p))
-
+    #===========================================================================
+    # METHOD  : LOG
+    # PURPOSE : toggle log file mode
+    #===========================================================================
     def LOG(self) :
           self.logfile = "calc.py.log"
           if not self.__log :
@@ -883,22 +1001,24 @@ class Calc(ItclObjectx, Frame) :
               self.__log = False
               self.__logfid.close()
               self.messagebox("log file \"" + self.logfile + "\" closed")
-
     #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     # basic calculator functions
     #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     #==========================================================================
-    # PSH: push token onto stack
+    # METHOD  : PSH
+    # PURPOSE : push token onto stack
     #==========================================================================
     def PSH (self, token) :
        self.STK.append(token)
     #==========================================================================
-    # POP: pop token from stack
+    # METHOD  : POP
+    # PURPOSE : pop token from stack
     #==========================================================================
     def POP (self) :
        return self.STK.pop()
     #==========================================================================
-    # PEX: pop expression from stack (stop before Stop)
+    # METHOD  : PEX
+    # PURPOSE : pop expression from stack (stop before Stop)
     #==========================================================================
     def PEX (self, Stop=[""]) :
         e = []
@@ -916,7 +1036,8 @@ class Calc(ItclObjectx, Frame) :
         else :
             return 0.0
     #==========================================================================
-    # STX: set accumulator
+    # METHOD  : STX
+    # PURPOSE : set accumulator
     #==========================================================================
     def STX (self, x) :
         self.x = []
@@ -928,31 +1049,34 @@ class Calc(ItclObjectx, Frame) :
             self.__logfid.write("expression:" + u)
             self.__logfid.flush()
     #==========================================================================
-    # STM: set memory
+    # METHOD  : STM
+    # PURPOSE : set memory
     #==========================================================================
     def STM (self, m) :
-        self.m = []
-        self.m.append(m)
+        self.m = m
         self.mem = 1
         self.__dispm__()
         self.mode = ">"
         self.__dispx__()
     #=======================================================================
-    # CLX: clear accumulator
+    # METHOD  : CLX
+    # PURPOSE : clear accumulator
     #==========================================================================
     def CLX(self) :
         self.x = ["0"]
         self.mode = ">"
         self.__dispx__()
     #==========================================================================
-    # CLM: clear memory
+    # METHOD  : CLM
+    # PURPOSE : clear memory
     #==========================================================================
     def CLM (self) :
         self.m = 0
         self.mem = 0
         self.__dispm__()
     #=======================================================================
-    # CLA: clear states
+    # METHOD  : CLA
+    # PURPOSE : clear states
     #==========================================================================
     def CLA(self) :
         self.drg = 0
@@ -960,9 +1084,11 @@ class Calc(ItclObjectx, Frame) :
         self.arc = 0
         self.__dispa__()
     #==========================================================================
-    # GTX: return x
-    # *  put decimal point on end of x if still in integer mode
-    #    before further processing
+    # METHOD  : GTX
+    # PURPOSE : return accumulator
+    # NOTES   :
+    #     *  put decimal point on end of x if still in integer mode
+    #        before further processing
     #==========================================================================
     def GTX (self) :
         if (self.mode == "I") :
@@ -972,7 +1098,8 @@ class Calc(ItclObjectx, Frame) :
         x = eval(string.join(self.x, ""))
         return x
     #==========================================================================
-    # GTM: return m
+    # METHOD  : GTM
+    # PURPOSE : return memory
     #==========================================================================
     def GTM (self) :
         if (not(self.mem)) :
@@ -983,10 +1110,22 @@ class Calc(ItclObjectx, Frame) :
     #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     # extra math functions
     #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+    #==========================================================================
+    # METHOD  : asinh
+    # PURPOSE : asinh
+    #==========================================================================
     def asinh(self, x) :
         return log(x + sqrt(x*x + 1.0))
+    #==========================================================================
+    # METHOD  : acosh
+    # PURPOSE : acosh
+    #==========================================================================
     def acosh(self, x) :
         return log(x + sqrt(x*x - 1.0))
+    #==========================================================================
+    # METHOD  : atanh
+    # PURPOSE : atanh
+    #==========================================================================
     def atanh(self, x) :
         if (x == 1.0) :
             return 100.0
@@ -996,7 +1135,8 @@ class Calc(ItclObjectx, Frame) :
     # windows
     #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     #==========================================================================
-    # __dispx__: re-display x, mode
+    # METHOD  : __dispx__
+    # PURPOSE : re-display accumulator, mode
     #==========================================================================
     def __dispx__(self) :
         x = string.join(self.x, "")
@@ -1008,7 +1148,8 @@ class Calc(ItclObjectx, Frame) :
         disp["state"] = DISABLED
         stat_s["text"] = self.mode
     #==========================================================================
-    # __dispm__: re-display mem
+    # METHOD  : __dispm__
+    # PURPOSE : re-display memory
     #==========================================================================
     def __dispm__(self) :
         stat_m = self.__Component["state_m"]
@@ -1017,7 +1158,8 @@ class Calc(ItclObjectx, Frame) :
         else :
             stat_m["text"] = ""
     #==========================================================================
-    # __dispa__: re-display drg, hyp, arc
+    # METHOD  : __dispa__
+    # PURPOSE : re-display drg, hyp, arc
     #==========================================================================
     def __dispa__(self) :
         stat_d = self.__Component["state_d"]
@@ -1038,12 +1180,14 @@ class Calc(ItclObjectx, Frame) :
         else :
             stat_h["text"] = ""
     #==========================================================================
-    # messagebox: display error or info
+    # METHOD  : messagebox
+    # PURPOSE : display error or info
     #==========================================================================
     def messagebox(self, message) :
         tkMessageBox.showinfo(message=message)
     #==========================================================================
-    # constant: constant toplevel
+    # METHOD  : constant
+    # PURPOSE : constant toplevel
     #==========================================================================
     def constant(self) :
         #self.messagebox("constant isn't implemented yet")
@@ -1122,7 +1266,8 @@ class Calc(ItclObjectx, Frame) :
         del self.__Component["constant_lbox"]
         return self.__constant_results
     #==========================================================================
-    # __constant_accept
+    # METHOD  : __constant_accept
+    # PURPOSE : constant dialog accept button callback
     #==========================================================================
     def __constant_accept(self) :
         top  = self.__Component["constant_top"]
@@ -1132,7 +1277,8 @@ class Calc(ItclObjectx, Frame) :
         self.__constant_results = results
         top.quit()
     #==========================================================================
-    # __constant_cancel
+    # METHOD  : __constant_cancel
+    # PURPOSE : constant dialog cancel button callback
     #==========================================================================
     def __constant_cancel(self) :
         top  = self.__Component["constant_top"]
