@@ -69,7 +69,7 @@ import math
 from Tkinter import *
 from decida.PlotBase import PlotBase
 from decida.Data import Data
-from decida.Selection_dialog import Selection_dialog
+from decida.SelectionDialog import SelectionDialog
 
 class Contourx(PlotBase) :
     """ plot line and color-band contours.
@@ -646,7 +646,7 @@ class Contourx(PlotBase) :
               ]
           ],
         ]
-        sd = Selection_dialog(self, title="Plot Settings", guispecs=specs)
+        sd = SelectionDialog(self, title="Plot Settings", guispecs=specs)
         V = sd.go()
         if V["ACCEPT"] :
             self["title"]             = V["title"]
