@@ -66,7 +66,7 @@ import re
 import numpy
 from decida.PlotBase import PlotBase
 from decida.Data import Data
-from decida.Selection_dialog import Selection_dialog
+from decida.SelectionDialog import SelectionDialog
 
 class Histogramx(PlotBase) :
     """ plot histogram of vector values.
@@ -533,7 +533,7 @@ class Histogramx(PlotBase) :
               ]
           ],
         ]
-        sd = Selection_dialog(self, title="Plot Settings", guispecs=specs)
+        sd = SelectionDialog(self, title="Plot Settings", guispecs=specs)
         V = sd.go()
         if V["ACCEPT"] :
             self["title"]             = V["title"]
