@@ -74,7 +74,7 @@ from decida.ItclObjectx      import ItclObjectx
 from decida.Data             import Data
 from decida.DataViewx        import DataViewx
 from decida.XYplotx          import XYplotx
-from decida.Selection_dialog import Selection_dialog
+from decida.SelectionDialog  import SelectionDialog
 from decida.EquationParser   import EquationParser
 from decida.Tckt             import Tckt
 import Tkinter
