@@ -1108,8 +1108,8 @@ class PLLphaseNoise(ItclObjectx, Frame) :
             ["fmin",    "minimum frequency [Hz]"],
             ["fmax",    "maximum frequency [Hz]"],
             ["rf",      "LPF resistor [ohm]"],
-            ["cf",      "LPF zero capacitor [F]"],
-            ["cd",      "LPF damping capacitor [F]"],
+            ["cf",      "LPF capacitor [F]"],
+            ["cd",      "LPF ripple-bypass capacitor [F]"],
             ["mp",      "DIV feed-back divider value"],
             ["icp",     "ICP current [A]"],
             ["kvco",    "VCO gain [Hz/V]"],
@@ -1192,8 +1192,6 @@ class PLLphaseNoise(ItclObjectx, Frame) :
     #--------------------------------------------------------------------------
     # METHOD  : recalculate
     # PURPOSE : force re-calculation
-    # NOTES :
-    #    * for non-gui applications
     #--------------------------------------------------------------------------
     def recalculate(self) :
         """ recalculate transfer functions, and output phase-noise.
@@ -1324,7 +1322,7 @@ class PLLphaseNoise(ItclObjectx, Frame) :
                 : Feed-backdivider value     M+1    = %d
                 : Loop-filter res.           Rf     = %-12.5g Kohm
                 : Loop-filter cap.           Cf     = %-12.5g pF
-                : Loop-filter damping cap.   Cd     = %-12.5g pF
+                : Loop-filter ripple-byp cap Cd     = %-12.5g pF
                 : Charge-pump current        Icp    = %-12.5g uA
                 : VCO gain                   Kvco   = %-12.5g MHz/V
                 : V2I pole                   fv2i   = %-12.5g MHz
