@@ -73,7 +73,7 @@ from decida.ItclObjectx      import ItclObjectx
 from decida.Data             import Data
 from decida.DataViewx        import DataViewx
 from decida.XYplotx          import XYplotx
-from decida.Selection_dialog import Selection_dialog
+from decida.SelectionDialog  import SelectionDialog
 from decida.EquationParser   import EquationParser
 import Tkinter
 from Tkinter import *
@@ -1028,7 +1028,7 @@ class Plotterx(ItclObjectx, Frame) :
         timestamp = time.time()
         datetime  = time.asctime(time.localtime(timestamp))
         f = open(file, "w")
-        f.write("#!/usr/bin/python2.6\n")
+        f.write("#! /usr/bin/env python\n")
         f.write("#" * 72 + "\n")
         f.write("# NAME : %s\n" % (file))
         f.write("# CREATED BY : Plotterx\n")
