@@ -68,7 +68,7 @@ import math
 from Tkinter import *
 from decida.PlotBase import PlotBase
 from decida.Data import Data
-from decida.Selection_dialog import Selection_dialog
+from decida.SelectionDialog import SelectionDialog
 
 class SmithChartx(PlotBase) :
     """ plot s-parameter data on a Smith chart.
@@ -595,7 +595,7 @@ class SmithChartx(PlotBase) :
               ]
           ],
         ]
-        sd = Selection_dialog(self, title="Plot Settings", guispecs=specs)
+        sd = SelectionDialog(self, title="Plot Settings", guispecs=specs)
         V = sd.go()
         if V["ACCEPT"] :
             self["title"]             = V["title"]
