@@ -66,7 +66,7 @@ import string
 import re
 import subprocess
 from decida.ItclObjectx      import ItclObjectx
-from decida.Selection_dialog import Selection_dialog
+from decida.SelectionDialog  import SelectionDialog
 from decida.FrameNotebook    import FrameNotebook
 import Tkinter
 from Tkinter import *
@@ -473,6 +473,8 @@ class TextWindow(ItclObjectx, Frame) :
             command=self.pipethrough_sort)
         editmenu.add_command(label="join spice continued lines",
             command=self.join_spice)
+        editmenu.add_command(label="join spectre continued lines",
+            command=self.join_spectre)
         editmenu.add_command(label="change highlight color",
             command=self.choose_color)
         editmenu.add_command(label="change comment character",
@@ -492,6 +494,8 @@ class TextWindow(ItclObjectx, Frame) :
         #---------------------------------------------------------------------
         text.focus()
         self.update()
+        if self.__toplevel:
+            self.__toplevel.wm_title("twin")
         if self.__openfile :
             self.fileread(self.__openfile)
         if self["wait"] :
@@ -1039,7 +1043,7 @@ class TextWindow(ItclObjectx, Frame) :
                  ["pos2", "ending position", ""],
             ]],
         ]
-        sd = Selection_dialog(self, title=guititle, guispecs=guispecs)
+        sd = SelectionDialog(self, title=guititle, guispecs=guispecs)
         V=sd.go()
         if not V["ACCEPT"] :
             return
@@ -1104,6 +1108,39 @@ class TextWindow(ItclObjectx, Frame) :
         self.clear()
         self.enter(lines)
     #==========================================================================
+    # METHOD : join_spectre
+    # PURPOSE : join spectre netlist continued lines
+    #==========================================================================
+    def join_spectre(self) :
+        """ join spectre netlist continued lines.
+        """
+        xlines = []
+        xline = ""
+        lines = self.getall()
+        lines = string.split(lines, "\n")
+        for line in lines :
+            line = re.sub("\r", "", line)
+            line = re.sub("\n", "", line)
+            line = re.sub("\t", " ", line)
+            line = string.strip(line)
+            if len(line) == 0:
+                if len(xline) > 0:
+                    xline = re.sub("[\t ]+", " ", xline)
+                    xlines.append(xline)
+                xline = ""
+            elif line[-1] == "\\" :
+                xline += line[0:-1]
+            else :
+                xline += line
+                xline = re.sub("[\t ]+", " ", xline)
+                xlines.append(xline)
+                xline = ""
+        if len(xline) > 0:
+            xline = re.sub("[\t ]+", " ", xline)
+            xlines.append(xline)
+        self.clear()
+        self.enter(string.join(xlines, "\n"))
+    #==========================================================================
     # METHOD : splitup
     # PURPOSE : split up text lines (also user command)
     #==========================================================================
